\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass{thesis}[2012/04/25 DBIS Thesis Package]


\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ExecuteOptions{a4paper,
	10pt,
	bibliography=totoc,
	listof=totoc,
	twoside,								
	openright,
	%pointlessnumbers,
	numbers=noenddot,
	headings=normal,
	chapterprefix,	% Kapitel mit zusätzlichem Titel "Kapitel" darstellen
	headsepline,	% Linie nach Kopfzeile
	DIV=9
}
\ProcessOptions\relax
\LoadClass{article}
\pagestyle{headings}
\RequirePackage[ngerman]{babel}
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}					% AL: Bessere Schrift trotz T1
\RequirePackage{microtype}						% AL: Verbessert den Schriftsatz
\RequirePackage{enumitem}						% alphanumerische nummerierung in enumerate
%\renewcommand{\sfdefault}{phv}
\renewcommand{\rmdefault}{bch}
%\renewcommand{\ttdefault}{pcr}
\RequirePackage{graphicx}
\RequirePackage{geometry}
%\geometry{a4paper, top=38mm, left=38mm, right=38mm, bottom=44mm,headsep=10mm, footskip=12mm}
\RequirePackage{verbatim}
\RequirePackage{tabularx}
\RequirePackage{url}
\RequirePackage{color}
\RequirePackage{amssymb}
\RequirePackage{setspace}
\RequirePackage{listings}
\RequirePackage{amsmath}					%js
\RequirePackage{booktabs}					%js 
\RequirePackage{multirow}					%js
\RequirePackage[left]{eurosym}				%js
\RequirePackage{amsthm}						%js
\RequirePackage{ragged2e}					%js

\RequirePackage{float}						%js
\RequirePackage[section]{placeins}			%js
\RequirePackage{epigraph}					%js
\setlength{\epigraphwidth}{0.4\textwidth}

\RequirePackage{longtable}					%js
\RequirePackage[printonlyused]{acronym}		%js			


%Floatzeug
\RequirePackage{placeins} %\FloatBarrier
\RequirePackage[bottom]{footmisc} %TABLE should not float under footnote

%Pseudocode
\RequirePackage{amsmath}
\RequirePackage{algorithm}
\RequirePackage{algpseudocode}
\algrenewcommand\algorithmicrequire{\textbf{Input:}}
\algrenewcommand\algorithmicensure{\textbf{Output:}}
\renewcommand\thealgorithm{\thechapter.\arabic{algorithm}} %alg numbering

%Diagramme
\RequirePackage{tikz}
\RequirePackage{tikz-qtree}
\RequirePackage{pgfplots}
\usetikzlibrary{shapes,arrows,positioning,tikzmark}

%Hurenkinder Schusterjungen
\clubpenalty10000
\widowpenalty10000
\displaywidowpenalty=10000  

\lstset{language=Java,
		  showstringspaces=false,
		  frame=single,
		  numbers=left,
		  basicstyle=\ttfamily,
		  numberstyle=\tiny,
		captionpos=b,
  		}


\theoremstyle{plain}
\newtheorem{theorem}{Theorem}
\newtheorem{satz}[theorem]{Satz}
\newtheorem{lemma}[theorem]{Lemma}
\newtheorem{proposition}[theorem]{Proposition}
\newtheorem{corollary}[theorem]{Korollar}
%js definition-umgebung setzen!
\theoremstyle{definition}	
\newtheorem{definition}[theorem]{Definition}
\newtheorem{claim}[theorem]{Behauptung}
\newtheorem{remark}[theorem]{Bemerkung}
\newtheorem{example}[theorem]{Beispiel}

% hier namen etc. einsetzen
\newcommand{\@fullname}{}
\newcommand{\@email}{}
\newcommand{\@headline}{}
\newcommand{\@titel}{}
\newcommand{\@jahr}{}
\newcommand{\@matnr}{}

\newif\if@betreuerSet
\@betreuerSetfalse
\newcommand{\@betreuer}{}
\newcommand{\@typ}{}
\newcommand{\@fakultaet}{}
\newcommand{\@institut}{}

\newcommand{\fullname}[1]{\renewcommand{\@fullname}{#1}}
\newcommand{\titel}[1]{\renewcommand{\@titel}{#1}}
\newcommand{\jahr}[1]{\renewcommand{\@jahr}{#1}}
\newcommand{\betreuer}[1]{\renewcommand{\@betreuer}{#1}\@betreuerSettrue}
\newcommand{\typ}[1]{\renewcommand{\@typ}{#1}}
\newcommand{\fakultaet}[1]{\renewcommand{\@fakultaet}{#1}}
\newcommand{\institut}[1]{\renewcommand{\@institut}{#1}}

\newcommand{\thefullname}[0]{\@fullname}
\newcommand{\thetitel}{\@titel}
\newcommand{\thejahr}{\@jahr}
\newcommand{\thebetreuer}{\@betreuer}
\newcommand{\thetyp}{\@typ}
\newcommand{\thefakultaet}{\@fakultaet}
\newcommand{\theinstitut}{\@institut}

\setlength{\parindent}{0pt}		
%setlength{\parskip}{1.4ex plus 0.35ex minus 0.3ex}

\RequirePackage{hyperref}

\renewcommand{\maketitle}[0]
{
	\thispagestyle{empty}
	\begin{flushright}	
		\includegraphics[width=7.5cm]{logo_uulm_sw.png}\vspace{3pt}\\ 
		\parbox[t]{7.5cm}{\small\bfseries
			\@fakultaet\\
			\mdseries \@institut}
	\end{flushright}
	\vspace{3cm} 
	\begin{center}
		{\bfseries \huge \@titel}\\[1em]
		{\large \@fullname}\\[2em]
		{\textit{\@typ}}\\[.5em]
		{Betreuer: \@betreuer}\\[.5em]
		\@jahr\\[.5em]	
	\end{center}
	\vfill
}

