\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass{thesis}[2012/04/25 DBIS Thesis Package]


\DeclareOption*{\PassOptionsToClass{\CurrentOption}{scrbook}}
\ExecuteOptions{a4paper,
	10pt,
	bibliography=totoc,
	listof=totoc,
	twoside,								
	openright,
	%pointlessnumbers,
	numbers=noenddot,
	headings=normal,
	chapterprefix,	% Kapitel mit zusätzlichem Titel "Kapitel" darstellen
	headsepline,	% Linie nach Kopfzeile
	DIV=9
}
\ProcessOptions\relax
\LoadClass{scrbook}
\pagestyle{headings}
\RequirePackage[ngerman]{babel}
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}					% AL: Bessere Schrift trotz T1
\RequirePackage{microtype}						% AL: Verbessert den Schriftsatz
\RequirePackage{enumitem}						% alphanumerische nummerierung in enumerate
%\renewcommand{\sfdefault}{bch}
\renewcommand{\rmdefault}{bch}
%\renewcommand{\ttdefault}{pcr}
\RequirePackage{graphicx}
\RequirePackage{geometry}
%\geometry{a4paper, top=38mm, left=38mm, right=38mm, bottom=44mm,headsep=10mm, footskip=12mm}
\RequirePackage{verbatim}
\RequirePackage{tabularx}
\RequirePackage{url}
\RequirePackage{color}
\RequirePackage{amssymb}
\RequirePackage{setspace}
\RequirePackage{listings}
\RequirePackage{amsmath}					%js
\RequirePackage{booktabs}					%js 
\RequirePackage{multirow}					%js
\RequirePackage[left]{eurosym}				%js
\RequirePackage{amsthm}						%js
\RequirePackage{ragged2e}					%js

\RequirePackage{float}						%js
\RequirePackage[section]{placeins}			%js
\RequirePackage{epigraph}					%js
\setlength{\epigraphwidth}{0.4\textwidth}

\RequirePackage{longtable}					%js
\RequirePackage[printonlyused]{acronym}		%js			

%Abstract
\newenvironment{prechapter}[1]{
   \onehalfspacing
    \chapter*{ \centering #1}%
}{}

%Floatzeug
\RequirePackage{placeins} %\FloatBarrier
\RequirePackage[bottom]{footmisc} %TABLE should not float under footnote

%Pseudocode
\RequirePackage{amsmath}
\RequirePackage{algorithm}
\RequirePackage{algpseudocode}
\algrenewcommand\algorithmicrequire{\textbf{Input:}}
\algrenewcommand\algorithmicensure{\textbf{Output:}}
\renewcommand\thealgorithm{\thechapter.\arabic{algorithm}} %alg numbering

%Diagramme
\RequirePackage{tikz}
\RequirePackage{tikz-qtree}
\RequirePackage{pgfplots}
\usetikzlibrary{shapes,arrows,positioning,tikzmark}

%Hurenkinder Schusterjungen
\clubpenalty10000
\widowpenalty10000
\displaywidowpenalty=10000  

\lstset{language=Java,
		  showstringspaces=false,
		  frame=single,
		  numbers=left,
		  basicstyle=\ttfamily,
		  numberstyle=\tiny,
		captionpos=b,
  		}




\theoremstyle{plain}
\newtheorem{theorem}{Theorem}[section]
\newtheorem{satz}[theorem]{Satz}
\newtheorem{lemma}[theorem]{Lemma}
\newtheorem{proposition}[theorem]{Proposition}
\newtheorem{corollary}[theorem]{Korollar}
%js definition-umgebung setzen!
\theoremstyle{definition}	
\newtheorem{definition}[theorem]{Definition}
\newtheorem{claim}[theorem]{Behauptung}
\newtheorem{remark}[theorem]{Bemerkung}
\newtheorem{example}[theorem]{Beispiel}



% hier namen etc. einsetzen
\newcommand{\@fullname}{\null}
\newcommand{\@email}{\null}
\newcommand{\@headline}{\null}
\newcommand{\@titel}{\null}
\newcommand{\@jahr}{\null}
\newcommand{\@matnr}{\null}

\newif\if@gutachterASet
\@gutachterASetfalse
\newcommand{\@gutachterA}{\null}


\newif\if@gutachterBSet
\@gutachterBSetfalse
\newcommand{\@gutachterB}{\null}


\newif\if@betreuerSet
\@betreuerSetfalse
\newcommand{\@betreuer}{\null}
\newcommand{\@typ}{\null}
\newcommand{\@fakultaet}{\null}
\newcommand{\@institut}{\null}
\newif\if@licenseSet
\@licenseSetfalse
\newcommand{\@license}{\null}

\newcommand{\fullname}[1]{\renewcommand{\@fullname}{#1}}
\newcommand{\email}[1]{\renewcommand{\@email}{#1}}
\newcommand{\headline}[1]{\renewcommand{\@headline}{#1}}
\newcommand{\titel}[1]{\renewcommand{\@titel}{#1}}
\newcommand{\jahr}[1]{\renewcommand{\@jahr}{#1}}
\newcommand{\matnr}[1]{\renewcommand{\@matnr}{#1}}
\newcommand{\gutachterA}[1]{\renewcommand{\@gutachterA}{#1}\@gutachterASettrue}
\newcommand{\gutachterB}[1]{\renewcommand{\@gutachterB}{#1}\@gutachterBSettrue}
\newcommand{\betreuer}[1]{\renewcommand{\@betreuer}{#1}\@betreuerSettrue}
\newcommand{\typ}[1]{\renewcommand{\@typ}{#1}}
\newcommand{\fakultaet}[1]{\renewcommand{\@fakultaet}{#1}}
\newcommand{\institut}[1]{\renewcommand{\@institut}{#1}}
\newcommand{\license}[1]{\renewcommand{\@license}{#1}\@licenseSettrue}

\newcommand{\thefullname}[0]{\@fullname}
\newcommand{\theemail}{\@email}
\newcommand{\theheadline}{\@headline}
\newcommand{\thetitel}{\@titel}
\newcommand{\thejahr}{\@jahr}
\newcommand{\thematnr}{\@matnr}
\newcommand{\thegutachterA}{\@gutachterA}
\newcommand{\thegutachterB}{\@gutachterB}
\newcommand{\thebetreuer}{\@betreuer}
\newcommand{\thetyp}{\@typ}
\newcommand{\thefakultaet}{\@fakultaet}
\newcommand{\theinstitut}{\@institut}
\newcommand{\thelicense}{\@license}



% farbe in tabellen
\RequirePackage{colortbl}
\definecolor{Gray}{rgb}{0.80784, 0.86667, 0.90196} 	%dunkelblau
\definecolor{Lightgray}{rgb}{0.9176, 0.95, 0.95686} %hellblau
\definecolor{Akzent}{rgb}{0.6627, 0.63529, 0.55294} %akzentfarbe
\setlength{\arrayrulewidth}{0.1pt}



\setlength{\parindent}{0pt}		
%setlength{\parskip}{1.4ex plus 0.35ex minus 0.3ex}

\setcounter{tocdepth}{2}	 % tiefe des inhaltsverzeichnisses
\setcounter{secnumdepth}{3} % Nummerierung der Überschriftentiefe festlegen

\RequirePackage{hyperref}

\renewcommand{\maketitle}[0]
{
	\thispagestyle{empty}
	\begin{flushright}	
		\includegraphics[width=7.4cm]{logo_uulm_sw.png}\vspace{3pt}\\ 
		\parbox[t]{7.4cm}{\bfseries \fontfamily{\sfdefault} \large
			\@fakultaet\\
			\mdseries \@institut}
	\end{flushright}
	\vspace{3cm} 
	\begin{center}
		{\bfseries \fontfamily{\sfdefault} \huge \@titel}\\[.5em]
		\footnotesize
		{\@typ{} an der Universität Ulm}
	\end{center}
	\vfill
	{			
		{ \bfseries \fontfamily{\sfdefault} \large Vorgelegt von:}\\
		{\@fullname\\ \@email\\ \@matnr}\\[2em]
		{\bfseries \fontfamily{\sfdefault} \large Gutachter:}\\                     
		{\@gutachterA\\ \@gutachterB}\\[2em]
		{\bfseries \fontfamily{\sfdefault} \large Betreuer:}\\ 
		\@betreuer\\[3em]
		\@jahr
	}
}


\renewcommand*\listalgorithmname{Algorithmenverzeichnis}

\newcommand{\impressum}[0]
{
	\thispagestyle{empty}
	{ \small
	  \flushleft
	  Fassung \today \\\vfill
	  \copyright~\@jahr~\@fullname\\[0.5em]
	
	\if@licenseSet
	\@license
	\fi
	}
}

\newcommand{\erklaerung}[0]
{
	\cleardoublepage
	\thispagestyle{empty}

	Name: \thefullname \hfill Matrikelnummer: \thematnr \vspace{2cm}

	\minisec{Erklärung}

	Ich erkläre, dass ich die Arbeit selbstständig verfasst und keine anderen als
	die angegebenen Quellen und Hilfsmittel verwendet habe.\vspace{2cm}

	Ulm, den \dotfill

	\hspace{10cm} {\footnotesize \thefullname}
}

